@@ -75,6 +75,7 @@ CGAP_PUBLIC_URL_PRD = 'https://cgap.hms.harvard.edu'
 
 CGAP_PUBLIC_URLS = {
     'cgap': CGAP_PUBLIC_URL_PRD,
+    'fourfront-cgap': CGAP_PUBLIC_URL_PRD,
     'data': CGAP_PUBLIC_URL_PRD,
     'staging': CGAP_PUBLIC_URL_STG,
 }
@@ -141,12 +142,12 @@ BEANSTALK_DEV_DATA_SETS = {
     'fourfront-webdev': 'prod',
 
     'fourfront-cgapdev': 'test',
-    'fourfront-cgaptest': 'test',
-    'fourfront-cgapwolf': 'test',
+    'fourfront-cgaptest': 'prod',
+    'fourfront-cgapwolf': 'prod',
 
     'cgap-dev': 'test',
-    'cgap-test': 'test',
-    'cgap-wolf': 'test',
+    'cgap-test': 'prod',
+    'cgap-wolf': 'prod',
 
 }
 
@@ -194,6 +195,8 @@ def blue_green_mirror_env(envname):
     For other envnames that aren't blue/green participants, this returns None.
     """
     if 'blue' in envname:
+        if 'green' in envname:
+            raise ValueError('A blue/green mirror env must have only one of blue or green in its name.')
         return envname.replace('blue', 'green')
     elif 'green' in envname:
         return envname.replace('green', 'blue')
@@ -321,7 +324,7 @@ def get_mirror_env_from_context(settings, allow_environ=ALLOW_ENVIRON_BY_DEFAULT
         return declared
     elif allow_guess:
         who_i_am = get_env_from_context(settings, allow_environ=allow_environ)
-        return guess_mirror_env(who_i_am)
+        return get_standard_mirror_env(who_i_am)
     else:
         return None
 
@@ -345,12 +348,14 @@ def get_standard_mirror_env(envname):
     return BEANSTALK_PROD_MIRRORS.get(envname, None)
 
 
-def guess_mirror_env(envname):
-    """
-    Deprecated. This function returns what get_standard_mirror_env(envname) returns.
-    (The name guess_mirror_env is believed to be confusing.)
-    """
-    return get_standard_mirror_env(envname)
+# guess_mirror_env was reatained for a while for compatibility. Please prefer get_standard_mirror_env.
+#
+# def guess_mirror_env(envname):
+#     """
+#     Deprecated. This function returns what get_standard_mirror_env(envname) returns.
+#     (The name guess_mirror_env is believed to be confusing.)
+#     """
+#     return get_standard_mirror_env(envname)
 
 
 def infer_repo_from_env(envname):
@@ -468,3 +473,11 @@ def classify_server_url(url, raise_error=True):
         'environment': environment,
         'is_stg_or_prd': is_stg_or_prd
     }
+
+
+def make_env_name_cfn_compatible(env_name: str) -> str:
+    """ Common IDs in Cloudformation forbid the use of '-', and we don't want to change
+        our environment name formatting so this simple method is provided to document this
+        behavior. ex: cgap-mastertest -> cgapmastertest
+    """
+    return env_name.replace('-', '')
